==> huaweicloudsdkdataartsstudio-3.1.112-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/list_security_dynamic_masking_policies_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListSecurityDynamicMaskingPoliciesResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'policies': 'list[DynamicMaskingPolicySet]'
    }

    attribute_map = {
        'total': 'total',
        'policies': 'policies'
    }

    def __init__(self, total=None, policies=None):
        """ListSecurityDynamicMaskingPoliciesResponse

        The model defined in huaweicloud sdk

        :param total: 动态脱敏策略总条数。
        :type total: int
        :param policies: 动态数据脱敏策略列表。
        :type policies: list[:class:`huaweicloudsdkdataartsstudio.v1.DynamicMaskingPolicySet`]
        """
        
        super(ListSecurityDynamicMaskingPoliciesResponse, self).__init__()

        self._total = None
        self._policies = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if policies is not None:
            self.policies = policies

    @property
    def total(self):
        """Gets the total of this ListSecurityDynamicMaskingPoliciesResponse.

        动态脱敏策略总条数。

        :return: The total of this ListSecurityDynamicMaskingPoliciesResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ListSecurityDynamicMaskingPoliciesResponse.

        动态脱敏策略总条数。

        :param total: The total of this ListSecurityDynamicMaskingPoliciesResponse.
        :type total: int
        """
        self._total = total

    @property
    def policies(self):
        """Gets the policies of this ListSecurityDynamicMaskingPoliciesResponse.

        动态数据脱敏策略列表。

        :return: The policies of this ListSecurityDynamicMaskingPoliciesResponse.
        :rtype: list[:class:`huaweicloudsdkdataartsstudio.v1.DynamicMaskingPolicySet`]
        """
        return self._policies

    @policies.setter
    def policies(self, policies):
        """Sets the policies of this ListSecurityDynamicMaskingPoliciesResponse.

        动态数据脱敏策略列表。

        :param policies: The policies of this ListSecurityDynamicMaskingPoliciesResponse.
        :type policies: list[:class:`huaweicloudsdkdataartsstudio.v1.DynamicMaskingPolicySet`]
        """
        self._policies = policies

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListSecurityDynamicMaskingPoliciesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdataartsstudio-3.1.151-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/list_security_dynamic_masking_policies_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListSecurityDynamicMaskingPoliciesResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'policies': 'list[DynamicMaskingPolicySet]'
    }

    attribute_map = {
        'total': 'total',
        'policies': 'policies'
    }

    def __init__(self, total=None, policies=None):
        r"""ListSecurityDynamicMaskingPoliciesResponse

        The model defined in huaweicloud sdk

        :param total: 动态脱敏策略总条数。
        :type total: int
        :param policies: 动态数据脱敏策略列表。
        :type policies: list[:class:`huaweicloudsdkdataartsstudio.v1.DynamicMaskingPolicySet`]
        """
        
        super(ListSecurityDynamicMaskingPoliciesResponse, self).__init__()

        self._total = None
        self._policies = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if policies is not None:
            self.policies = policies

    @property
    def total(self):
        r"""Gets the total of this ListSecurityDynamicMaskingPoliciesResponse.

        动态脱敏策略总条数。

        :return: The total of this ListSecurityDynamicMaskingPoliciesResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        r"""Sets the total of this ListSecurityDynamicMaskingPoliciesResponse.

        动态脱敏策略总条数。

        :param total: The total of this ListSecurityDynamicMaskingPoliciesResponse.
        :type total: int
        """
        self._total = total

    @property
    def policies(self):
        r"""Gets the policies of this ListSecurityDynamicMaskingPoliciesResponse.

        动态数据脱敏策略列表。

        :return: The policies of this ListSecurityDynamicMaskingPoliciesResponse.
        :rtype: list[:class:`huaweicloudsdkdataartsstudio.v1.DynamicMaskingPolicySet`]
        """
        return self._policies

    @policies.setter
    def policies(self, policies):
        r"""Sets the policies of this ListSecurityDynamicMaskingPoliciesResponse.

        动态数据脱敏策略列表。

        :param policies: The policies of this ListSecurityDynamicMaskingPoliciesResponse.
        :type policies: list[:class:`huaweicloudsdkdataartsstudio.v1.DynamicMaskingPolicySet`]
        """
        self._policies = policies

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListSecurityDynamicMaskingPoliciesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
